abacusai.chat_bot_response — AbacusAI documentation

# `abacusai.chat_bot_response`

## Module Contents

### Classes

`ChatBotResponse` | A response from the chat bot

class abacusai.chat_bot_response.ChatBotResponse(client, answer=None, chatHistory=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A response from the chat bot

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - answer (str) – The response from the chat bot

    - chatHistory (list) – The chat history as a list of dicts with is_user and text entries

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict